/**
 * Utility for generating row / column headers
 */
import { TitleAnchor, TitleConfig } from 'vega-typings';
import { FacetChannel } from '../../channel';
import { Config } from '../../config';
import { CoreHeader } from '../../header';
import { FacetFieldDef } from '../../spec/facet';
import { RowCol, VgComparator, VgMarkGroup, VgTitle } from '../../vega.schema';
import { Model } from '../model';
import { HeaderChannel, HeaderComponent, HeaderType, LayoutHeaderComponent, LayoutHeaderComponentIndex } from './component';
export declare function assembleTitleGroup(model: Model, channel: FacetChannel): {
    name: string;
    type: string;
    role: string;
    title: {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[];
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame?: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
};
export declare function defaultHeaderGuideAlign(headerChannel: HeaderChannel, angle: number, anchor?: TitleAnchor): {
    align: string;
} | {
    align?: undefined;
};
export declare function defaultHeaderGuideBaseline(angle: number, channel: FacetChannel): {
    baseline: string;
} | {
    baseline?: undefined;
};
export declare function assembleHeaderGroups(model: Model, channel: HeaderChannel): VgMarkGroup[];
export declare function assembleLabelTitle(facetFieldDef: FacetFieldDef<string>, channel: FacetChannel, config: Config): {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: "left" | "center" | "right";
    };
    angle?: import("vega-typings/types").NumberValue;
    baseline: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: import("vega-typings/types").TextBaseline;
    };
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient: string | import("vega-typings/types").SignalRef;
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align?: import("vega-typings/types").AlignValue;
    angle?: import("vega-typings/types").NumberValue;
    baseline: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: import("vega-typings/types").TextBaseline;
    };
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient: string | import("vega-typings/types").SignalRef;
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: "left" | "center" | "right";
    };
    angle?: import("vega-typings/types").NumberValue;
    baseline?: import("vega-typings/types").TextBaselineValue;
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient: string | import("vega-typings/types").SignalRef;
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align?: import("vega-typings/types").AlignValue;
    angle?: import("vega-typings/types").NumberValue;
    baseline?: import("vega-typings/types").TextBaselineValue;
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient: string | import("vega-typings/types").SignalRef;
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: "left" | "center" | "right";
    };
    angle?: import("vega-typings/types").NumberValue;
    baseline: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: import("vega-typings/types").TextBaseline;
    };
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align?: import("vega-typings/types").AlignValue;
    angle?: import("vega-typings/types").NumberValue;
    baseline: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: import("vega-typings/types").TextBaseline;
    };
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align: string | import("vega-typings/types").SignalRef | {
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        value: string | number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        field: import("vega-typings/types").Field;
    } | {
        scale: import("vega-typings/types").Field;
        band: number | boolean;
    } | {
        scale: import("vega-typings/types").Field;
        range: number | boolean;
    } | {
        value: "left" | "center" | "right";
    };
    angle?: import("vega-typings/types").NumberValue;
    baseline?: import("vega-typings/types").TextBaselineValue;
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
} | {
    text: string | import("vega-typings/types").SignalRef | string[] | {
        signal: string;
    };
    subtitle?: string | import("vega-typings/types").SignalRef | string[];
    name?: string;
    interactive?: boolean;
    style: string | string[];
    zindex?: number;
    encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
    anchor?: import("vega-typings/types").AnchorValue;
    frame: import("vega-typings/types").StringValue;
    offset?: import("vega-typings/types").NumberValue;
    align?: import("vega-typings/types").AlignValue;
    angle?: import("vega-typings/types").NumberValue;
    baseline?: import("vega-typings/types").TextBaselineValue;
    dx?: import("vega-typings/types").NumberValue;
    dy?: import("vega-typings/types").NumberValue;
    color?: import("vega-typings/types").ColorValue;
    font?: import("vega-typings/types").StringValue;
    fontSize?: import("vega-typings/types").NumberValue;
    fontStyle?: import("vega-typings/types").StringValue;
    fontWeight?: import("vega-typings/types").FontWeightValue;
    lineHeight?: import("vega-typings/types").NumberValue;
    limit?: import("vega-typings/types").NumberValue;
    orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
    subtitleColor?: import("vega-typings/types").ColorValue;
    subtitleFont?: import("vega-typings/types").StringValue;
    subtitleFontSize?: import("vega-typings/types").NumberValue;
    subtitleFontStyle?: import("vega-typings/types").StringValue;
    subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
    subtitleLineHeight?: import("vega-typings/types").NumberValue;
    subtitlePadding?: import("vega-typings/types").NumberValue;
};
export declare function assembleHeaderGroup(model: Model, channel: HeaderChannel, headerType: HeaderType, layoutHeader: LayoutHeaderComponent, headerCmpt: HeaderComponent): {
    axes: import("vega-typings/types").Axis[];
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    from: {
        data: string;
    };
    sort: VgComparator;
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    from: {
        data: string;
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    name: string;
    type: string;
    role: string;
} | {
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    name: string;
    type: string;
    role: string;
} | {
    title: {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient: string | import("vega-typings/types").SignalRef;
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: import("vega-typings/types").TextBaseline;
        };
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align: string | import("vega-typings/types").SignalRef | {
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            value: string | number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            field: import("vega-typings/types").Field;
        } | {
            scale: import("vega-typings/types").Field;
            band: number | boolean;
        } | {
            scale: import("vega-typings/types").Field;
            range: number | boolean;
        } | {
            value: "left" | "center" | "right";
        };
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    } | {
        text: string | import("vega-typings/types").SignalRef | string[] | {
            signal: string;
        };
        subtitle?: string | import("vega-typings/types").SignalRef | string[];
        name?: string;
        interactive?: boolean;
        style: string | string[];
        zindex?: number;
        encode?: import("vega-typings/types").TitleEncode | Partial<Record<import("vega-typings/types").EncodeEntryName, import("vega-typings/types").TextEncodeEntry>>;
        anchor?: import("vega-typings/types").AnchorValue;
        frame: import("vega-typings/types").StringValue;
        offset?: import("vega-typings/types").NumberValue;
        align?: import("vega-typings/types").AlignValue;
        angle?: import("vega-typings/types").NumberValue;
        baseline?: import("vega-typings/types").TextBaselineValue;
        dx?: import("vega-typings/types").NumberValue;
        dy?: import("vega-typings/types").NumberValue;
        color?: import("vega-typings/types").ColorValue;
        font?: import("vega-typings/types").StringValue;
        fontSize?: import("vega-typings/types").NumberValue;
        fontStyle?: import("vega-typings/types").StringValue;
        fontWeight?: import("vega-typings/types").FontWeightValue;
        lineHeight?: import("vega-typings/types").NumberValue;
        limit?: import("vega-typings/types").NumberValue;
        orient?: "left" | "right" | "none" | import("vega-typings/types").SignalRef | "top" | "bottom";
        subtitleColor?: import("vega-typings/types").ColorValue;
        subtitleFont?: import("vega-typings/types").StringValue;
        subtitleFontSize?: import("vega-typings/types").NumberValue;
        subtitleFontStyle?: import("vega-typings/types").StringValue;
        subtitleFontWeight?: import("vega-typings/types").FontWeightValue;
        subtitleLineHeight?: import("vega-typings/types").NumberValue;
        subtitlePadding?: import("vega-typings/types").NumberValue;
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    name: string;
    type: string;
    role: string;
} | {
    encode: {
        update: {
            [x: string]: {
                signal: string;
            };
        };
    };
    name: string;
    type: string;
    role: string;
} | {
    axes: import("vega-typings/types").Axis[];
    name: string;
    type: string;
    role: string;
} | {
    name: string;
    type: string;
    role: string;
};
export declare function getLayoutTitleBand(titleAnchor: TitleAnchor, headerChannel: HeaderChannel): any;
export declare function assembleLayoutTitleBand(headerComponentIndex: LayoutHeaderComponentIndex, config: Config): RowCol<number>;
export declare function assembleHeaderProperties(config: Config, facetFieldDef: FacetFieldDef<string>, channel: FacetChannel, properties: (keyof CoreHeader)[], propertiesMap: {
    [k in keyof CoreHeader]: keyof TitleConfig;
}): Partial<VgTitle>;
//# sourceMappingURL=assemble.d.ts.map